{% load i18n %}
{% if IS_SU %}
<style>
    #django-su-warning {
        position: fixed;
        bottom: 0;
        width: 100%;
        color: white;
        background-color: red;
        text-align: center;
        font-size: 25px;
        z-index: 5000;
    }
</style>
<div id="django-su-warning">
    {% trans "WARNING: You have assumed the identity of another account!" %}
</div>
{% endif %}
