{% extends "admin/base_site.html" %}

{% load i18n static %}

{% block title %}{% trans "Login as" %} | {% trans 'Django site admin' %}{% endblock %}

{% block extrahead %}
  {{ block.super }}
  {% if form.use_ajax_select %}
    <script type="text/javascript" src="{% static 'ajax_select/js/bootstrap.js' %}"></script>
    <script type="text/javascript" src="{% static 'ajax_select/js/ajax_select.js' %}"></script>
    <link href="{% static 'ajax_select/css/ajax_select.css' %}" rel="stylesheet" type="text/css" />
  {% endif %}
  {{ form.media }}
  <link href="{% static 'admin/css/forms.css' %}" type="text/css" rel="stylesheet">
{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
  <form action="." method="POST">{% csrf_token %}
    {{ form }}
    <div class="submit-row">
      <input type="submit" name="submit" class="default" value="{% trans "Change Login" %}"/>
    </div>
  </form>
{% endblock %}
